/**
 * @module dixim
 * @submodule autoDownload
 */
dixim.namespace('dixim.autoDownload');

/**
 * @module autoDownload
 * @submodule filter-setting-dialog-view
 */

(function() {
var FilterSettingDialogView;
var prototype;
var superConstructor;
var _ = dixim.ctt.ResourceBundle.get;
var Event = dixim.event.Event;
var ModalDialogView = dixim.common.ModalDialogView;
var $ = dixim.ctt.jQuery;
var escape = dixim.xml.escape;

/**
 * @class FilterSettingDialogView
 * @constructor
 * @param {Object} configs
 */
FilterSettingDialogView = function(configs) {
    ModalDialogView.call(this, configs);
};

dixim.inherit(FilterSettingDialogView, ModalDialogView);
dixim.autoDownload.FilterSettingDialogView = FilterSettingDialogView;
prototype = FilterSettingDialogView.prototype;
superConstructor = FilterSettingDialogView.superConstructor;

var SELECT = 'select';
var DELETE = 'delete';
var CHANGE = 'change';
var ADD = 'add';
var TEMPLATE_BODY_CONTENT = [
    '<div id="filter-setting-operation-bar" class="filter_action_bar modal_hd_btns">',
    '<label>', '<button id="auto-download-filter-select" class="ui-btn ui-shadow ui-corner-all">', '${select}', '</button>', '</label>',
    '<label>', '<button id="auto-download-filter-delete" class="ui-btn ui-shadow ui-corner-all">', '${delete}', '</button>', '</label>',
    '<label>', '<button id="auto-download-filter-change" class="ui-btn ui-shadow ui-corner-all">', '${edit}', '</button>', '</label>',
    '<label>', '<button id="auto-download-filter-add" class="ui-btn ui-shadow ui-corner-all">', '${append}', '</button>', '</label>',
    '</div>',
    '<div id="filter-setting-list" class="dlg_scroll">',
    '<div id="filter-setting-no-filter" class="txt_none error-text-field">', '</div>',
    '<table>', '</table>',
    '</div>',
].join('');

/**
 * @method _initialize
 * @protected
 * @param {Object} configs
 */
prototype._initialize = function(configs) {
    configs = configs || {};

    configs.id = configs.id || '';
    configs.id = [configs.id, 'filter-setting-dialog-'].join('');

    configs.bodyContent = TEMPLATE_BODY_CONTENT
        .replace('${select}', _('action_bar_select'))
        .replace('${delete}', _('action_bar_delete'))
        .replace('${edit}', _('action_bar_edit'))
        .replace('${append}', _('action_bar_append'));

    configs.doubleDialog = true;
    configs.contentHeight = configs.contentHeight || '300px';
    configs.buttons = [
        {text: _('dialog_return_menu'), click: dixim.proxy(this.hide, this)},
    ];
    configs.title = _('auto_download_setting_filter_setting');

    this._selectedFilter = {};

    superConstructor.prototype._initialize.call(this, configs);
};

prototype._render = function() {
    $('#auto-download-filter-select').on('click', dixim.proxy(this._clickSelect, this));
    $('#auto-download-filter-delete').on('click', dixim.proxy(this._clickDelete, this));
    $('#auto-download-filter-change').on('click', dixim.proxy(this._clickChange, this));
    $('#auto-download-filter-add').on('click', dixim.proxy(this._clickAdd, this));

    superConstructor.prototype._render.call(this);
};

prototype.updateActionBarStatus = function() {
    var checkLen = $('#filter-setting-list [type="checkbox"]').length;

    $('#auto-download-filter-select,#auto-download-filter-delete,#auto-download-filter-change').prop('disabled', true);

    if (checkLen > 0) {
        $('#auto-download-filter-select,#auto-download-filter-delete,#auto-download-filter-change').prop('disabled', false);
    }
};

prototype.addFilter = function(filter) {
    if ($(['#', filter.filterId].join('')).length > 0) {
        return;
    }

    $('#filter-setting-list table').append([
        '<tr>', '<td>',
        '<label class="select-pointer">',
        '<input type="checkbox" id="', filter.filterId, '"/>',
        '<span>', '</span>',
        '</label>',
        '</td>', '<td>',
        '<p class="filter-name">', escape(filter.filterName), '</p>',
        '</td>', '</tr>',
    ].join(''));

    $('#filter-setting-list table tr:last-child [type="checkbox"]').on('change', filter, dixim.proxy(this._changeCheckbox, this));
};

prototype._changeCheckbox = function(e) {
    if (e.currentTarget.checked) {
        this._selectedFilter[e.data.filterId] = e.data;
    } else {
        delete this._selectedFilter[e.data.filterId]
    }
};

prototype.noFilter = function() {
    this.error(_('auto_download_filter_setting_no_filter'));
};

prototype.switchSelect = function() {
    var checkboxSelector = $('#filter-setting-list [type="checkbox"]');
    var numberOfNotChecked = checkboxSelector.not(':checked').length;

    checkboxSelector.prop('checked', (numberOfNotChecked > 0)).trigger('change');
};

prototype.error = function(text) {
    var selector = $('#filter-setting-no-filter');

    selector.html([
        '<span>', text, '</span>',
    ].join(''));
    selector.addClass('txt_none error-text-field');
};

prototype._clickSelect = function() {
    this.dispatchEvent(new Event(SELECT));
};

prototype._clickDelete = function() {
    this.dispatchEvent(new Event(DELETE, this._selectedFilter));
};

prototype._clickChange = function() {
    this.dispatchEvent(new Event(CHANGE, this._selectedFilter));
};

prototype._clickAdd = function() {
    this.dispatchEvent(new Event(ADD));
};

prototype.cleanList = function() {
    this._selectedFilter = {};
    $('#filter-setting-list').html([
        '<div id="filter-setting-no-filter" class="txt_none error-text-field">', '</div>',
        '<table>', '</table>'
    ].join(''));
};

}());
