/**
 * @module dixim
 * @submodule common
 */
dixim.namespace('dixim.common');

/**
 * @module common
 * @submodule menu-view
 */

(function() {
var MenuView;
var prototype;
var superConstructor;
var _ = dixim.ctt.ResourceBundle.get;
var Event = dixim.event.Event;
var EventTarget = dixim.event.EventTarget;
var UiUtils = dixim.common.UiUtils;
var $ = dixim.ctt.jQuery;

/**
 * @class MenuView
 * @constructor
 * @param {Object} configs
 */
MenuView = function(configs) {
    EventTarget.call(this);
    this._initialize(configs);
};

dixim.inherit(MenuView, EventTarget);
dixim.common.MenuView = MenuView;
prototype = MenuView.prototype;
superConstructor = MenuView.superConstructor;

var PREV = 'prev';

/**
 * @method _initialize
 * @protected
 * @param {Object} configs
 */
prototype._initialize = function(configs) {
    configs = configs || {};

    this._title = configs.title || '';
    this._menuList = configs.menuList || [];
    this._uiUtils = UiUtils;
};

/**
 * @method show
 */
prototype.show = function() {
    var menuListLen = this._menuList.length;

    $('.rootPage').html([
        '<div class="contents" data-enhance="false">',
        '<h2 id="tit_page">', this._title, '</h2>',
        '<div class="contents_inner">',
        '<ul id="menu_settings_content" class="list_btn txt_m list_next list_menu">',
        '</ul>',
        '</div>',
        '</div>',
    ].join(''));

    this._uiUtils.cleanActionSettingBar();
    this._uiUtils.cleanActionBar();
    $('.art_tit').text(this._title);
    $('.btn_prev').show().off('click').on('click', dixim.proxy(this._clickPrev, this));

    for (var i = 0; i < menuListLen; i += 1) {
        this._addMenuList(this._menuList[i]);
    }
};

/**
 * @method hide
 */
prototype.hide = function() {
   $('.rootPage').empty();
};

prototype._addMenuList = function(data) {
    $('#menu_settings_content').append([
        '<li>', '<a href="#">', _(data.strId), '</a>', '</li>',
    ].join(''));
    $('#menu_settings_content li:last-child').on('click', data, dixim.proxy(this._clickMenu, this));
};

prototype._clickPrev = function() {
    this.dispatchEvent(new Event(PREV));
};

prototype._clickMenu = function(e) {
    this.dispatchEvent(new Event(e.data.eventParam));
};

}());
