/**
 * Holds utility codes.
 *
 * @module dixim 
 * @submodule common
 */
(function() {
dixim.namespace('dixim.common');
}());

(function() {
var UiUtils;
var _ = dixim.ctt.ResourceBundle.get;
var Utils = dixim.ctt.util.Utils;
var $ = dixim.ctt.jQuery;
var eventObj = function(name, action, callback, bf) {
    this.name = name;
    this.action = action;
    this.callback = callback;
    this.bf = bf;
}
var eventStack = [];

UiUtils = {
    showActionSettingBar: function(id, callback) {
        var selector = $(['#', id].join('')).closest('.bar_btn');

        selector.show().on('click', callback);
    },
    hideActionSettingBar: function(id) {
        var selector = $(['#', id].join('')).closest('.bar_btn');

        selector.hide().off('click');
    },
    cleanActionSettingBar: function() {
        $('.action_bar_top .bar_btn').hide().off('click');
        $('.action_bar .bar_btn').hide().off('click');
    },
    setActionBar: function(id, callback) {
        var text = '';

        switch(id) {
            case 'ab_select':
                text = _('action_bar_select');
                break;
            case 'ab_allow':
                text = _('action_bar_allow');
                break;
            case 'ab_deny':
                text = _('action_bar_deny');
                break;
            case 'ab_delete':
                text = _('action_bar_delete');
                break;
            case 'ab_apply':
                text = _('action_bar_apply');
                break;
            case 'ab_format':
                text = _('action_bar_format');
                break;
            case 'ab_edit':
                text = _('action_bar_edit');
                break;
            case 'ab_append':
                text = _('action_bar_append');
                break;
            case 'ab_operate':
                text = _('action_bar_operate');
                break;
            case 'ab_download':
                text = _('action_bar_download');
                break;
            case 'ab_auth':
                text = _('action_bar_auth');
                break;
            case 'ab_unlock':
                text = _('action_bar_unlock');
                break;
            case 'ab_sync':
                text = _('action_bar_sync');
                break;
        }
        $('.action_bar_bottom .bar_contents').append([
            '<a id="', id, '">', text, '</a>',
        ].join(''));
        $(['.action_bar_bottom .bar_contents #', id].join('')).on('click', callback);
        $('.action_bar_bottom').show();
        $('.ui-page').css('padding-top', '135px');
    },
    cleanActionBar: function() {
        $('.action_bar_bottom').hide();
        $('.action_bar_bottom .bar_contents a').remove();
        $('.ui-page').css('padding-top', '90px');
    },
    enableActionBar: function(id) {
        $(['.action_bar_bottom .bar_contents #', id].join('')).removeClass('disable').prop('disabled', '');
    },
    disableActionBar: function(id) {
        $(['.action_bar_bottom .bar_contents #', id].join('')).addClass('disable').prop('disabled');
    },
    addEffect: function(selector) {
        $(selector).off('touchstart touchend touchcancel mousedown mouseup mouseleave');
        $(selector).on('touchstart mousedown', function() {
            $(this).not(':disabled').css('opacity', '0.5').css('-moz-opacity', '0.5').css('filter', 'alpha(opacity=50)');
        }).on('touchend touchcancel mouseup mouseleave', function() {
            $(this).not(':disabled').css('opacity', '').css('-moz-opacity', '').css('filter', '');
        });
    },
    addEventListenerElm: function(elm, action, callback, bf) {
        if (elm == null) return;
    
        if (typeof elm.length === 'undefined') {
            elm.addEventListener( action, callback, bf);
        } else {
            for (var i=0; i < elm.length ; i++) {
                elm[i].addEventListener( action, callback, bf);
            }
        }
    },
    removeEventListenerElm: function(elm, action, callback, bf) {
        if (elm == null) return;
    
        if (typeof elm.length === 'undefined') {
            elm.removeEventListener( action, callback, bf);
        } else {
            for (var i=0; i < elm.length ; i++) {
                elm[i].removeEventListener( action, callback, bf);
            }
        }
    },
    setEventListener: function(name, action, callback, bf) {
        var elm = document.getElementById(name);
        if (elm == null) {
            elm = document.getElementsByName(name);
        }
        if (elm == null) return;
    
        var obj = new eventObj(name, action, callback, bf);
        UiUtils.removeEventListener(obj);
        eventStack.push(obj);

        UiUtils.addEventListenerElm( elm, action, callback, bf);
    },
    removeEventListener: function(obj) {
        var cnt = eventStack.length;
        for (var i=0 ; i < cnt ; i++) {
            var o = eventStack[i];
            if (o.name == obj.name && o.action == obj.action) {
                eventStack.splice(i, 1);
                var elm = document.getElementById(o.name);
                if (elm == null) {
                    elm = document.getElementsByName(name);
                }
                if (elm != null) {
                    UiUtils.removeEventListenerElm( elm,  o.action, o.callback, o.bf);
                }
                break;
            }
        }
    },
    switchTopMenuCode: function(is_home) {
        var necessary = ['css_welcome', 'css_welcome-rollover'];
        var necessaryLen = necessary.length;
        var unnecessary = ['css_default'];
        var unnecessaryLen = unnecessary.length;

        if (is_home) {
            for (var i = 0; i < necessaryLen; i += 1) {
                $(['[name="', necessary[i], '"]'].join('')).prop('disabled', true);
            }
            for (var i = 0; i < unnecessaryLen; i += 1) {
                $(['[name="', unnecessary[i], '"]'].join('')).prop('disabled', false);
            }
            $.getScript('lib/common/jquery.mobile.min.js');
        } else {
            for (var i = 0; i < necessaryLen; i += 1) {
                $(['[name="', necessary[i], '"]'].join('')).prop('disabled', false);
            }
            for (var i = 0; i < unnecessaryLen; i += 1) {
                $(['[name="', unnecessary[i], '"]'].join('')).prop('disabled', true);
            }
        }
    },
    clearEventListener: function() {
        while (eventStack.length) {
            UiUtils.removeEventListener(eventStack[0]);
        }
    },
    textFocusEvent: function() {
        var focusLock = false;
        return {
            set: function(tgt, tmp) {
                if (Utils.isUserAgent('ipod') && Utils.isUserAgent('touch') && Utils.isUserAgent('iphone\ os\ 7') && (! Utils.isBrowserMode())) {
                    $(tgt).off('.focus');
                    $(tgt).on('tap.focus', function() {
                        var thisId = $(this).prop('id');
                        var focusTimer;
    
                        if (focusLock) return false;
                        focusLock = true;
                        focusTimer = setInterval(function() {
                            var interval_w_height = $(window).height();
    
                            if (w_height-260 >= interval_w_height) {
                                $(tmp).focus();
                                setTimeout(function() {
                                    $(['#', thisId].join('')).focus();
                                    clearInterval(focusTimer);
                                    focusLock = false;
                                }, 100);
                            }
                        }, 100);
                        return false;
                    });
                }
            }
        };
    },
    clearPanelOnTextField: function(textFieldSelector) {
        var tfs = $(textFieldSelector);
        var tfsId = $(textFieldSelector).prop('id');
        var check = (Utils.isUserAgent('ipod') && Utils.isUserAgent('touch') && Utils.isUserAgent('iphone\ os\ 7') && (! Utils.isBrowserMode()));
    
        return {
            set: function() {
                if (check) {
                    $(tfs).closest('div').append(['<div id="', tfsId, '_panel" class="clear_panel"></div>'].join(''));
                    $(['#', tfsId, '_panel.clear_panel'].join(''))
                        .css('width', $(tfs).outerWidth(true))
                        .css('height', $(tfs).outerHeight(true))
                        .css('top', $(tfs).position().top)
                        .css('left', $(tfs).position().left);
                    $(['#', tfsId, '_panel.clear_panel'].join('')).on('tap', function() {
                        $(tfs).focus();
                        return false;
                    });
                }
            },
            reposition: function() {
                if (check) {
                    $(['#', tfsId, '_panel.clear_panel'].join(''))
                        .css('top', $(tfs).position().top)
                        .css('left', $(tfs).position().left);
                }
            }
        };
    },
};

dixim.common.UiUtils = UiUtils;
}());
