/**
 * @module dixim
 * @submodule download
 */
dixim.namespace('dixim.download');

/**
 * @module download
 * @submodule download-menu-controller
 */

(function() {
var DownloadMenuController;
var prototype;
var superConstructor;
var DownloadMenuView = dixim.contents.DownloadMenuView;
var EventTarget = dixim.event.EventTarget;
var UiFunctionManager = dixim.ctt.util.UiFunctionManager;
var Configs = dixim.ctt.Configs;
var ResourceBundle = dixim.ctt.ResourceBundle;

/**
 * @class DownloadMenuController
 * @constructor
 * @param {Object} configs
 */
DownloadMenuController = function(configs) {
    EventTarget.call(this);
    this._initialize(configs);
};

dixim.inherit(DownloadMenuController, EventTarget);
dixim.download.DownloadMenuController = DownloadMenuController;
prototype = DownloadMenuController.prototype;
superConstructor = DownloadMenuController.superConstructor;

UiFunctionManager.set('download');

var DOWNLOAD = 'download';
var AUTO_DOWNLOAD = 'autoDownload';
var EONKYO = 'eonkyo';
var PREV = 'prev';

/**
 * @method _initialize
 * @protected
 * @param {Object} configs
 */
prototype._initialize = function(configs) {
    configs = configs || {};

    ResourceBundle.reset();
    Configs.set('resourceBundlePath', 'lang/download/');

    this._view = new DownloadMenuView(configs);
    this._view.addEventListener(DOWNLOAD, this._clickDownload, this);
    this._view.addEventListener(AUTO_DOWNLOAD, this._clickAutoDownload, this);
    this._view.addEventListener(EONKYO, this._clickEonkyo, this);
    this._view.addEventListener(PREV, this._clickPrev, this);

    this._parentContext = configs.parentContext;
};

/**
 * @method start
 */
prototype.start = function() {
    this._view.show();
};

/**
 * @method stop
 */
prototype.stop = function() {
    this._view.hide();
};

prototype._clickDownload = function() {
    var controller;
    var query = {};

    query.parentContext = this;
    controller = new dixim.download.DownloadController(query);
    controller.start();
};

prototype._clickAutoDownload = function() {
    var controller;
    var query = {};

    query.parentContext = this;
    controller = new dixim.autoDownload.AutoDownloadController(query);
    controller.start();
};

prototype._clickEonkyo = function() {
    var controller;
    var query = {};

    query.parentContext = this;
    controller = new dixim.download.EonkyoMenuController(query);
    controller.start();
};

prototype._clickPrev = function() {
    this.stop();
    this._parentContext.start();
};

}());
