/**
 * @module dixim
 * @submodule server
 */
dixim.namespace('dixim.server');

/**
 * @module server
 * @submodule parental-check-dialog-controller
 */

(function() {
var ParentalCheckDialogController;
var prototype;
var superConstructor;
var ParentalCheckDialogView = dixim.server.ParentalCheckDialogView;
var EventTarget = dixim.event.EventTarget;
var Event = dixim.event.Event;
var _ = dixim.ctt.ResourceBundle.get;
var ApiClientTransfer = dixim.common.ApiClientTransfer;

/**
 * @class ParentalCheckDialogController
 * @constructor
 * @param {Object} configs
 */
ParentalCheckDialogController = function(configs) {
    EventTarget.call(this);
    this._initialize(configs);
};

dixim.inherit(ParentalCheckDialogController, EventTarget);
dixim.server.ParentalCheckDialogController = ParentalCheckDialogController;
prototype = ParentalCheckDialogController.prototype;
superConstructor = ParentalCheckDialogController.superConstructor;

var SUCCESS = 'success';
var ERROR = 'error';
var OK = 'ok';

/**
 * @method _initialize
 * @protected
 * @param {Object} configs
 */
prototype._initialize = function(configs) {
    configs = configs || {};

    configs.title = _('server_menu_parental');

    this._model = new ApiClientTransfer();
    this._model.addEventListener('matchPin', this._successMatchPin, this);
    this._model.addEventListener('matchPinError', this._errorMatchPin, this);

    this._view = new ParentalCheckDialogView(configs);
    this._view.addEventListener(OK, this._clickOk, this);

    this._pinCode = null;
};

/**
 * @method start
 */
prototype.start = function() {
    this._view.show();
};

/**
 * @method stop
 */
prototype.stop = function() {
    this._view.stopIndicator();
    this._view.hide();
};

prototype._successMatchPin = function() {
    this.stop();
    this.dispatchEvent(new Event(SUCCESS, {pinCode: this._pinCode}));
};

prototype._errorMatchPin = function() {
    this.stop();
    this.dispatchEvent(new Event(ERROR));
};

prototype._clickOk = function(e) {
    var query = {};

    this._view.startIndicator();
    this._pinCode = e.args.pinCode;

    query.code = this._pinCode;
    this._model.matchPin(query);
};

}());
