/**
 * @module dixim
 * @submodule server
 */
dixim.namespace('dixim.server');

/**
 * @module server
 * @submodule public-folder-wizard-select-folder-dialog-view
 */

(function() {
var PublicFolderWizardSelectFolderDialogView;
var prototype;
var superConstructor;
var ModalDialogView = dixim.common.ModalDialogView;
var EventTarget = dixim.event.EventTarget;
var Event = dixim.event.Event;
var _ = dixim.ctt.ResourceBundle.get;
var $ = dixim.ctt.jQuery;
var Configs = dixim.ctt.Configs;
var Template = dixim.ctt.util.Template;

/**
 * @class PublicFolderWizardSelectFolderDialogView
 * @constructor
 * @param {Object} configs
 */
PublicFolderWizardSelectFolderDialogView = function(configs) {
    ModalDialogView.call(this, configs);
};

dixim.inherit(PublicFolderWizardSelectFolderDialogView, ModalDialogView);
dixim.server.PublicFolderWizardSelectFolderDialogView = PublicFolderWizardSelectFolderDialogView;
prototype = PublicFolderWizardSelectFolderDialogView.prototype;
superConstructor = PublicFolderWizardSelectFolderDialogView.superConstructor;

var NEXT = 'next';
var SELECT_DIRECTORY = 'selectDirectory';

var SEPARATE = Template.SEPARATE;
var TEMPLATE_BODY_CONTENT = [
    '<div class="description-field dlg_main_msg">', '<span>', '${description}', '</span>', '</div>',
    '<div id="publicFolderList" class="list-field dlg_scroll list_next">',
    '<table>',
    '</table>',
    '</div>',
].join('');

/**
 * @method _initialize
 * @protected
 * @param {Object} configs
 */
prototype._initialize = function(configs) {
    configs = configs || {};

    configs.id = configs.id || '';
    configs.id = [configs.id, 'public-folder-wizard-select-folder-dialog-'].join('');

    configs.bodyContent = TEMPLATE_BODY_CONTENT.
        replace('${description}', _('server_public_folder_add_description'));

    configs.contentHeight = "300px";
    configs.buttons = [
        {
            text: _('dialog_close'),
            click: dixim.proxy(this.hide, this),
        },
        {
            text: _('dialog_next'),
            click: dixim.proxy(this._clickNext, this),
        },
    ];

    this._pathList = [];

    superConstructor.prototype._initialize.call(this, configs);
};

prototype.addRow = function(path) {
    var rowSelector;
    var len;
    var pathStr;

    pathStr = (path === SEPARATE) ? [SEPARATE] : path.split(SEPARATE);
    for (var i = 0; i < pathStr.length; i += 1) {
        if (pathStr[i] === '') {
            pathStr.splice(i, 1);
            i -= 1;
        }
    }
    pathStr = pathStr[pathStr.length - 1];

    $('#publicFolderList table').append([
        '<tr>',
        '<td class="select-server-checkbox">',
        '<label class="select-pointer">',
        '<input type="checkbox" />', '<span>', '</span>',
        '</label>',
        '</td>',
        '<td class="select-directory">',
        '<img src="', Configs.get('imagePath'), '/ico_list_folder.png', '" width="40px">',
        '<span class="info-title-text">', pathStr, '</span>',
        '</td>',
        '</tr>',
    ].join(''));
    rowSelector = $('#publicFolderList table tr:last-child');

    rowSelector.find('td').not('.select-server-checkbox').on('click', {path: path}, dixim.proxy(this._clickDirectory, this));
    rowSelector.find('[type="checkbox"]').on('click', {path: path}, dixim.proxy(this._clickCheckbox, this));
};

prototype.noRow = function() {
    this.error(_('server_public_folder_add_no_folder'));
};

prototype.changeCheckbox = function() {
    var checkboxSelector = $('#publicFolderList table [type="checkbox"]:checked');

    if (checkboxSelector.length === 1) {
        this.enableButton(_('dialog_next'));
    } else {
        this.disableButton(_('dialog_next'));
    }
};

prototype._removePathList = function(path) {
    for (var i = 0, len = this._pathList.length; i < len; i += 1) {
        if (this._pathList[i] === path) {
            this._pathList.splice(i, 1);
            break;
        }
    }
};

prototype.error = function(text) {
     $('#publicFolderList').html([
       '<div class="error-text-field txt_none">', '<span>', text, '</span>', '</div>',
    ].join(''));
};

prototype._clickCheckbox = function(e) {
    this.changeCheckbox();
    if (e.target.checked) {
        this._pathList.push(e.data.path);
    } else {
        this._removePathList(e.data.path);
    }
};

prototype._clickDirectory = function(e) {
    this.dispatchEvent(new Event(SELECT_DIRECTORY, {path: e.data.path}));
};

prototype._clickNext = function() {
    this.dispatchEvent(new Event(NEXT, {path: this._pathList[0]}));
};

prototype.cleanList = function() {
    $('#publicFolderList').html(['<table>', '</table>'].join(''));
    this._pathList = [];
};

}());
