/**
 * @module dixim
 * @submodule vdms
 */
dixim.namespace('dixim.vdms');

/**
 * @module vdms
 * @submodule aggregation-operation-menu-dialog-view
 */

(function() {
var AggregationOperationMenuDialogView;
var prototype;
var superConstructor;
var ModalDialogView = dixim.common.ModalDialogView;
var Event = dixim.event.Event;
var _ = dixim.ctt.ResourceBundle.get;

/**
 * @class AggregationOperationMenuDialogView
 * @constructor
 * @param {Object} configs
 */
AggregationOperationMenuDialogView = function(configs) {
    ModalDialogView.call(this, configs);
};

dixim.inherit(AggregationOperationMenuDialogView, ModalDialogView);
dixim.vdms.AggregationOperationMenuDialogView = AggregationOperationMenuDialogView;
prototype = AggregationOperationMenuDialogView.prototype;
superConstructor = AggregationOperationMenuDialogView.superConstructor;

var CHANGE = 'change';
var PAUSE = 'pause';
var RESTART = 'restart';
var DELETE = 'delete';

/**
 * @method _initialize
 * @protected
 * @param {Object} configs
 */
prototype._initialize = function(configs) {
    var isAggregatedDevice = configs.isAggregatedDevice;

    configs = configs || {};

    configs.id = configs.id || '';
    configs.id = [configs.id, 'aggregation-operation-menu-dialog-'].join('');

    configs.title = _('dialog_title_operation');
    configs.closeButton = dixim.proxy(this.hide, this);
    configs.buttons = [
        {text: _('dialog_close'), click: dixim.proxy(this.hide, this)}
    ];

    configs.lists = [];
    configs.lists.push({
        text: (isAggregatedDevice) ? _('vdms_aggregation_operation_non_aggregate') : _('vdms_aggregation_operation_aggregate'),
        click: dixim.proxy(this._clickChange, this),
    });

    if (isAggregatedDevice) {
        configs.lists.push({
            text: _('vdms_aggregation_operation_pause'),
            click: dixim.proxy(this._clickPause, this),
        });
        configs.lists.push({
            text: _('vdms_aggregation_operation_restart'),
            click: dixim.proxy(this._clickRestart, this),
        });
    }
    configs.lists.push({
        text: _('vdms_aggregation_operation_delete'),
        click: dixim.proxy(this._clickDelete, this),
    });

    superConstructor.prototype._initialize.call(this, configs);
};

prototype._clickChange = function() {
    this.dispatchEvent(new Event(CHANGE));
};

prototype._clickPause = function() {
    this.dispatchEvent(new Event(PAUSE));
};

prototype._clickRestart = function() {
    this.dispatchEvent(new Event(RESTART));
};

prototype._clickDelete = function() {
    this.dispatchEvent(new Event(DELETE));
};

}());
