/**
 * @module ctt
 * @submodule download-destination-wizard-page-view
 */
(function() {
var Event = dixim.event.Event;
var Template = dixim.ctt.util.Template;
var WizardPageView = dixim.ctt.WizardPageView;
var TickerView = dixim.ctt.TickerView;
var _ = dixim.ctt.ResourceBundle.get;
var $ = dixim.ctt.jQuery;

var DownloadDestinationWizardPageView;
var prototype;
var superConstructor;

/**
 * @class DownloadDestinationWizardPageView
 * @extends WizardPageView
 * @constructor
 * @param {Object} configs
 */
DownloadDestinationWizardPageView = function(configs) {
  WizardPageView.call(this, configs);
};
dixim.inherit(DownloadDestinationWizardPageView, WizardPageView);
dixim.ctt.DownloadDestinationWizardPageView = DownloadDestinationWizardPageView;
prototype = DownloadDestinationWizardPageView.prototype;
superConstructor = DownloadDestinationWizardPageView.superConstructor;

/**
 * Triggered when the view has been rendered.
 *
 * @event render
 */
var RENDER = 'render';

/**
 * @event cancel
 */
var CANCEL = 'cancel';

/**
 * @event next
 */
var NEXT = 'next';

var TEMPLATE_PAGE_BODY = ['<div class="ctt-download-destination-wizard-page-view">',
                          '<div class="ctt-download-destination-wizard-page-view-description">${description}</div>',
                          '<div class="ctt-download-destination-wizard-page-view-container-list"></div>',
                          '</div>'].join('');

var TEMPLATE_LOADING_OVERLAY = Template.LOADING_OVERLAY;

/**
 * @method _initialize
 * @protected
 * @param {Object} configs
 */
prototype._initialize = function(configs) {
  var buttons;
  var cfg;

  cfg = {
    title: _('ctt_download_wizard_title'),
    bodyContent: TEMPLATE_PAGE_BODY.replace('${description}', _('ctt_download_destination_wizard_page_view_description'))
  };

  cfg = dixim.extend(cfg, configs);
  buttons = [
    {
      text: _('ctt_transfer_wizard_button_label_next'),
      click: $.proxy(this._didClickNext, this),
      'class': 'ctt-download-destination-wizard-page-view-button-next'
    },
    {
      text: _('ctt_transfer_wizard_button_label_cancel'),
      click: $.proxy(this._didClickCancel, this),
      align: 'left'
    }
  ];

  cfg.buttons = buttons;
  superConstructor.prototype._initialize.call(this, cfg);

  this._loadingOverlay = null;
  this._ticker = null;
};

prototype._didRenderDialog = function(e) {
  var v = this._view;

  this._loadingOverlay = $(TEMPLATE_LOADING_OVERLAY);
  this._ticker = new TickerView({
    containerNode: $('.ctt-download-destination-wizard-page-view-description', v),
    type: 'error'
  });

  superConstructor.prototype._didRenderDialog.call(this, e);
};

prototype._didOpenDialog = function(e) {
  var v = this._view;
  var list;
  var desc;

  superConstructor.prototype._didOpenDialog.call(this, e);

  list = $('.ctt-download-destination-wizard-page-view-container-list', v);
  desc = $('.ctt-download-destination-wizard-page-view-description', v);
  list.height(Math.floor(v.height() - desc.outerHeight()));
};

prototype._didClickNext = function(e) {
  this.dispatchEvent(new Event(NEXT));
};

prototype._didClickCancel = function(e) {
  this.dispatchEvent(new Event(CANCEL));
};

prototype.getBodyContent = function() {
  return $('.ctt-download-destination-wizard-page-view-container-list', this._view);
};

prototype.enableNextButton = function() {
  this.enableButton('.ctt-download-destination-wizard-page-view-button-next');
};

prototype.disableNextButton = function() {
  this.disableButton('.ctt-download-destination-wizard-page-view-button-next');
};

prototype.showActivityIndicator = function() {
  var o = this._loadingOverlay;
  var p = this._view;

  this.disableButtons();
  o.appendTo(p).width(p.innerWidth()).height(p.innerHeight()).show();
};

prototype.hideActivityIndicator = function() {
  this.enableButtons();
  this._loadingOverlay.hide(100).detach();
};

prototype.showError = function(error) {
  this._showError(error);
};

prototype._showError = function(error) {
  this._ticker.setText(error);
  this._ticker.show();
};

}());