/**
 * @module ctt
 * @submodule renaming-view
 */
(function() {
var Event = dixim.event.Event;
var ModalDialogView = dixim.ctt.ModalDialogView;
var TickerView = dixim.ctt.TickerView;
var Template = dixim.ctt.util.Template;
var _ = dixim.ctt.ResourceBundle.get;
var $ = dixim.ctt.jQuery;

var RenamingView;
var prototype;
var superConstructor;

/**
 * @class RenamingView
 * @extends ModalDialogView
 * @constructor
 * @param {Object} configs
 */
RenamingView = function(configs) {
  ModalDialogView.call(this, configs);
};
dixim.inherit(RenamingView, ModalDialogView);
dixim.ctt.RenamingView = RenamingView;
prototype = RenamingView.prototype;
superConstructor = RenamingView.superConstructor;

var TEMPLATE_CONTENT_BOX = '<div class="ctt-renaming-view-wrapper" />';

var TEMPLATE_BODY_CONTENT = ['<div class="ctt-renaming-view">',
                               '<div class="ctt-renaming-view-description">${desc}</div>',
                               '<div class="ctt-renaming-view-ticker-wrapper"></div>',
                               '<div class="ctt-renaming-view-form-wrapper">',
                                 '<form class="ctt-renaming-view-form"><table>',
                                   '<tr class="ctt-renaming-view-form-row ctt-renaming-view-form-old-name-row">',
                                     '<td>${oldName}</td>',
                                     '<td class="ctt-renaming-view-form-row-value"></td></tr>',
                                   '<tr class="ctt-renaming-view-form-row ctt-renaming-view-form-new-name-row">',
                                     '<td>${newName}</td>',
                                     '<td class="ctt-renaming-view-form-row-value"><input type="text" name="newName" /></td></tr>',
                                 '</table></form>',
                               '</div>',
                             '</div>'].join('');

/**
 * Triggered when the cancel button was clicked.
 *
 * @event cancel
 */
var CANCEL = 'cancel';

/**
 * Triggered when the rename button was clicked.
 *
 * @event rename
 */
var RENAME = 'rename';

/**
 * @method _initialize
 * @protected
 * @param {Object} configs
 */
prototype._initialize = function(configs) {
  var buttons;
  var bodyContent;

  configs  = configs || {};

  buttons = [
    {
      text: _('ctt_renaming_view_button_label_rename'),
      'class': 'ctt-renaming-view-button-rename', 
      click: $.proxy(this._didClickRename, this)
    },
    {
      text: _('ctt_dialog_button_label_cancel'),
      click: $.proxy(this._didClickCancel, this),
      align: 'left'
    }
  ];

  bodyContent = TEMPLATE_BODY_CONTENT.
                replace('${desc}', _('ctt_renaming_view_description')).
                replace('${oldName}', _('ctt_renaming_view_form_row_label_old_name')).
                replace('${newName}', _('ctt_renaming_view_form_row_label_new_name'));

  configs.title = _('ctt_renaming_view_title');
  configs.contentBox = configs.contentBox || TEMPLATE_CONTENT_BOX;
  configs.bodyContent = configs.bodyContent || bodyContent;
  configs.buttons = buttons;
  configs.width = 480;
  configs.height = 'auto';
  configs.maxHeight = 340;

  this._descriptionNode = null;
  this._ticker = null;
  this._formNode = null;
  this._targetItem = null;

  superConstructor.prototype._initialize.call(this, configs);
};

prototype._didRenderDialog = function(e) {
  var v = this._view;
  var f;

  this._descriptionNode = $('.ctt-renaming-view-description', v);
  this._ticker = new TickerView({
    containerNode: $('.ctt-renaming-view-ticker-wrapper', v),
    type: 'error'
  });
  f = $('form.ctt-renaming-view-form', v);

  f.bind('submit', $.proxy(this._didSubmitNewName, this));
  this._formNode = f;

  superConstructor.prototype._didRenderDialog.call(this, e);
};

prototype._didTitlebarCloseButtonClick = function(e) {
  e.preventDefault();
  this._didCancel();
};

prototype._didClickCancel = function(e) {
  this._didCancel();
};

prototype._didCancel = function() {
  this.dispatchEvent(new Event(CANCEL));
};

prototype._didClickRename = function(e) {
  this._didInvokeRename();
};

prototype._didSubmitNewName = function(e) {
  e.preventDefault();
  this._didInvokeRename();
};

prototype._didInvokeRename = function() {
  this.dispatchEvent(new Event(RENAME, {newName: this._getNewName(), targetItem: this._targetItem}));
};

/**
 * @method showError
 * @param {String} text
 */
prototype.showError = function(text) {
  this._showError(text);
};

prototype._showError = function(text) {
  text = text || '';

  this._ticker.setText(text);
  this._ticker.show();
};

prototype._getNewName = function() {
  return $('input[type="text"][name="newName"]', this._formNode).val();
};

prototype.updateTargetItem = function(item) {
  this._updateTargetItem(item);
};

prototype._updateTargetItem = function(item) {
  this._targetItem = item;
  $('.ctt-renaming-view-form-old-name-row > td + td').text(item.title || '');
  $('.ctt-renaming-view-form-new-name-row input[type="text"]').val('');
};

prototype.showActivityIndicator = function() {
  var buttonSet;
  var icon;
  var dialog = this._view.parent();

  this._ticker.hide(false);
  this.disableButtons();
  icon = $(Template.LOADING_ICON_SMALL);
  buttonSet = $('.ui-dialog-buttonset', dialog);
  $(buttonSet).append(icon);
};

prototype.hideActivityIndicator = function() {
  var buttonSet;
  var dialog = this._view.parent();

  this.enableButtons();
  buttonSet = $('.ui-dialog-buttonset', dialog);
  $('.ctt-loading', buttonSet).remove();
};

}());