/**
 * @module ctt
 * @submodule application-toolbar-view
 */
(function() {
var Event = dixim.event.Event;
var $ = dixim.ctt.jQuery;
var AutoDeleteApiClient = dixim.ctt.api.AutoDeleteApiClient;
var ContentsTransferApiClient = dixim.ctt.api.ContentsTransferApiClient;

var CheckSpec;

/**
 * @class CheckSpec
 * @constructor
 * @param {Object} configs
 */
CheckSpec = function(configs) {
  this._initialize.call(this, configs);
};
dixim.ctt.CheckSpec = CheckSpec;
prototype = CheckSpec.prototype;

/**
 * @method _initialize
 * @protected
 * @param {Object} configs
 */
prototype._initialize = function(configs) {
  this.specs = {};
  this._auto_delete_model = new AutoDeleteApiClient();
  this._transfer_model = new ContentsTransferApiClient();
};

prototype.check = function() {
  this.checkIsAutoDelete();
  this.checkIsCompression();
};

prototype.checkIsAutoDelete = function() {
  this._auto_delete_model.addEventListener('getAutoDeleteStatus', this._didGetAutoDownloadStatus, this);
  this._auto_delete_model.addEventListener('getAutoDeleteStatusError', this._didGetAutoDownloadStatus, this);
  this._auto_delete_model.getstatus();
};

prototype._didGetAutoDownloadStatus = function(e) {
  var status = e.args.session.connection.status;
  if (status === 404) {
    this.specs.isAutoDelete = false;
  } else {
    this.specs.isAutoDelete = true;
  }
};

prototype.checkIsCompression = function() {
  this._transfer_model.addEventListener('fetchAvailabilityCompression', this._didFetchAvailability, this);
  this._transfer_model.addEventListener('fetchAvailabilityCompressionError', this._didFetchAvailability, this);
  this._transfer_model.fetchAvailabilityCompression();
};

prototype._didFetchAvailability = function(e) {
  var status = e.args.session.connection.status;
  if (status === 404) {
    this.specs.isCompression = false;
  } else {
    this.specs.isCompression = true;
  }
};

prototype.getSpecs = function() {
  return this.specs;
};
}());
