/**
 * @module ctt
 * @submodule scheduled-recording-wizard-page-view
 */
(function() {
var Event = dixim.event.Event;
var WizardPageView = dixim.ctt.WizardPageView;
var Form = dixim.ctt.util.Form;
var _ = dixim.ctt.ResourceBundle.get;
var $ = dixim.ctt.jQuery;

var ScheduledRecordingWizardPageView;
var prototype;
var superConstructor;

/**
 * @class ConfirmationWizardPageView
 * @extends WizardPageView
 * @constructor
 * @param {Object} configs
 */
ScheduledRecordingWizardPageView = function(configs) {
  WizardPageView.call(this, configs);
};
dixim.inherit(ScheduledRecordingWizardPageView, WizardPageView);
dixim.ctt.ScheduledRecordingWizardPageView = ScheduledRecordingWizardPageView;
prototype = ScheduledRecordingWizardPageView.prototype;
superConstructor = ScheduledRecordingWizardPageView.superConstructor;

var TEMPLATE_SCHEDULE = ['<span class="ctt-scheduled-recording-wizard-page-view-form-schedule-date">${date}</span>',
                         '<span class="ctt-scheduled-recording-wizard-page-view-form-schedule-time">',
                         Form.createTimeSelector(),
                         '</span>'].join('');

var TEMPLATE = ['<div class="ctt-scheduled-recording-wizard-page-view">',
                  '<div class="ctt-scheduled-recording-wizard-page-view-description">${description}</div>',
                  '<div class="ctt-scheduled-recording-wizard-page-view-form-wrapper">',
                    '<form class="ctt-scheduled-recording-wizard-page-view-form"><table>',
                      '<tr class="ctt-scheduled-recording-wizard-page-view-form-method ctt-scheduled-recording-wizard-page-view-form-method-selected"><td><input type="radio" name="method" value="immediate" checked="checked" /></td><td>${immediate}</td></tr>',
                      '<tr class="ctt-scheduled-recording-wizard-page-view-form-method"><td><input type="radio" name="method" value="scheduled" /></td><td>${scheduled}</td></tr>',
                      '<tr class="ctt-scheduled-recording-wizard-page-view-form-schedule">',
                        '<td>&nbsp;</td><td>',
                          TEMPLATE_SCHEDULE,
                        '</td></tr>',
                    '</table></form>',
                  '</div>',
                '</div>'
                ].join('');

/**
 * Triggered when the view has been rendered.
 * 
 * @event render
 */
var RENDER = 'render';

/**
 * @method _initialize
 * @protected
 * @param {Object} configs
 * @param {Boolean} configs.isDownloadMoveIn
 */
prototype._initialize = function(configs) {
  var buttons;
  var cfg = {};

  this._isDownloadMoveIn = !!configs.isDownloadMoveIn;
  if (this._isDownloadMoveIn) {
    cfg.title = _('ctt_download_wizard_title');
    cfg.bodyContent = TEMPLATE.
                      replace('${date}', Form.createDateSelector()).
                      replace('${description}', _('ctt_scheduled_download_wizard_page_view_description')).
                      replace('${immediate}', _('ctt_scheduled_download_wizard_page_view_method_label_immediate')).
                      replace('${scheduled}', _('ctt_scheduled_download_wizard_page_view_method_label_scheduled'));
  } else {
    cfg.title = _('ctt_transfer_wizard_title');
    cfg.bodyContent = TEMPLATE.
                      replace('${date}', Form.createDateSelector()).
                      replace('${description}', _('ctt_scheduled_recording_wizard_page_view_description')).
                      replace('${immediate}', _('ctt_scheduled_recording_wizard_page_view_method_label_immediate')).
                      replace('${scheduled}', _('ctt_scheduled_recording_wizard_page_view_method_label_scheduled'));
  }

  cfg = dixim.extend(cfg, configs);
  buttons = [
    {
      text: _('ctt_transfer_wizard_button_label_next'),
      click: $.proxy(this._didClickNext, this)
    },
    {
      text: _('ctt_transfer_wizard_button_label_back'),
      click: $.proxy(this._didClickBack, this)
    },
    {
      text: _('ctt_transfer_wizard_button_label_cancel'),
      click: $.proxy(this._didClickCancel, this),
      align: 'left'
    }
  ];

  cfg.buttons = buttons;
  this._form = null;
  superConstructor.prototype._initialize.call(this, cfg);
};

prototype._didRenderDialog = function(e) {
  var v = this._view;
  var form;
  var date;
  var min;
  var hour;
  var msec;

  date = Form.getNextDateRange();
  min = date.getMinutes();
  hour = date.getHours();
  msec = new Date(date.getFullYear(), date.getMonth(), date.getDate()).getTime();

  form = $('.ctt-scheduled-recording-wizard-page-view-form', v);
  $('select[name="date"] option[value="' + msec + '"]', form).attr({'selected': true});
  $('select[name="hour"] option[value="' + hour + '"]', form).attr({'selected': true});
  $('select[name="min"] option[value="' + min + '"]', form).attr({'selected': true});
  $('.ctt-scheduled-recording-wizard-page-view-form-schedule select', form).attr({'disabled': true});

  $(form).on('click', '.ctt-scheduled-recording-wizard-page-view-form-method', function(e) {
    var target = $(this);
    var cls = 'ctt-scheduled-recording-wizard-page-view-form-method-selected';
    var radioSel = 'input[type="radio"][name="method"]';
    var radio;
    var selects;

    if (!target.hasClass(cls)) {
      target.siblings(['.', cls].join('')).
             removeClass(cls).
             find(radioSel).
             attr('checked', false);

      target.addClass(cls);
      radio = target.find(radioSel).first();
      radio.attr('checked', true);

      selects = $('.ctt-scheduled-recording-wizard-page-view-form-schedule select', form);
      if (radio.val() === 'scheduled') {
        selects.removeAttr('disabled');
      } else {
        selects.attr('disabled', true);
      }
    }
  });

  this._form = form;

  superConstructor.prototype._didRenderDialog.call(this, e);
};

prototype._didClickNext = function(e) {
  this.dispatchEvent(new Event('next'));
};

prototype._didClickBack = function(e) {
  this.dispatchEvent(new Event('back'));
};

prototype._didClickCancel = function(e) {
  this.dispatchEvent(new Event('cancel'));
};

/**
 * @method getSelectedDate
 * @return {Date}
 */
prototype.getSelectedDate = function() {
  var date;
  var hour;
  var min;

  date = parseInt($('select[name="date"] option:selected', this._form).val(), 10);
  hour = parseInt($('select[name="hour"] option:selected', this._form).val(), 10);
  min = parseInt($('select[name="min"] option:selected', this._form).val(), 10);

  date = new Date(date);
  date.setHours(hour, min, 0, 0);
  return date;
};

/**
 * @method getSelectedMethod
 * @return {String} "immediate" or "scheduled"
 */
prototype.getSelectedMethod = function() {
  var val;

  val = $('input[name="method"]:checked', this._form).val();
  if (val === 'scheduled') {
    return val;
  } else {
    return "immediate";
  }
};

}());
