
/**
 * @module ctt
 * @submodule transfer-wizard-controller
 */
(function() {
var Event = dixim.event.Event;
var WizardPageStackController = dixim.ctt.WizardPageStackController;
var DmsListingWizardPageController = dixim.ctt.DmsListingWizardPageController;

var TransferWizardController;
var prototype;
var superConstructor;

/**
 * Provides a wizard to collect information for
 * transferring the contents specified.
 *
 * @class TransferWizardController
 * @extends WizardPageStackController
 * @constructor
 * @param {Object} configs
 * @param {Object[]} configs.targetItems
 * @param {ContentsTransferApiClient} configs.model
 * @param {Boolean} [configs.enableWol=true] enables/disables WOL related functions which handle off-line DMSs.
 * @param {Boolean} [configs.enableScheduledTransferring=true] enables/disables Scheduled Transferring related functions.
 */
TransferWizardController = function(configs) {
  WizardPageStackController.call(this, configs);
};
dixim.inherit(TransferWizardController, WizardPageStackController);
dixim.ctt.TransferWizardController = TransferWizardController;
prototype = TransferWizardController.prototype;
superConstructor = TransferWizardController.superConstructor;

/**
 * @method _initialize
 * @protected
 * @param {Object} configs
 * @param {Object[]} configs.targetItems
 * @param {ContentsTransferApiClient} configs.model
 * @param {Boolean} [configs.enableWol=true] enables/disables WOL related functions which handle off-line DMSs.
 * @param {Boolean} [configs.enableScheduledTransferring=true] enables/disables Scheduled Transferring related functions.
 */
prototype._initialize = function(configs) {
  var cfgs = {
    enableWol: true,
    enableScheduledTransferring: true
  };

  cfgs = dixim.extend(cfgs, configs);

  superConstructor.prototype._initialize.call(this, cfgs);

  this.setRegistryEntry('targetItems', cfgs.targetItems);
  this.setRegistryEntry('model', cfgs.model);
  this.setRegistryEntry('enableWol', cfgs.enableWol);
  this.setRegistryEntry('enableScheduledTransferring',
                        cfgs.enableScheduledTransferring);
  this._rootController = new DmsListingWizardPageController();
};

}());
