/**
 * @module ctt
 * @submodule dms-listing-wizard-page-view
 */
(function() {
var Event = dixim.event.Event;
var Template = dixim.ctt.util.Template;
var WizardPageView = dixim.ctt.WizardPageView;
var TickerView = dixim.ctt.TickerView;
var _ = dixim.ctt.ResourceBundle.get;
var $ = dixim.ctt.jQuery;

var DmsListingWizardPageView;
var prototype;
var superConstructor;

/**
 * @class DmsListingWizardPageView
 * @extends WizardPageView
 * @constructor
 * @param {Object} configs
 */
DmsListingWizardPageView = function(configs) {
  WizardPageView.call(this, configs);
};
dixim.inherit(DmsListingWizardPageView, WizardPageView);
dixim.ctt.DmsListingWizardPageView = DmsListingWizardPageView;
prototype = DmsListingWizardPageView.prototype;
superConstructor = DmsListingWizardPageView.superConstructor;

/**
 * Triggered when the view has been rendered.
 * 
 * @event render
 */
var RENDER = 'render';

/**
 * @event delete
 */
var DELETE = 'delete';

/**
 * @event cancel
 */
var CANCEL = 'cancel';

/**
 * @event next
 */
var NEXT = 'next';

var TEMPLATE_PAGE_BODY = ['<div class="ctt-dms-listing-wizard-page-view">',
                          '<div class="ctt-dms-listing-wizard-page-view-description">${description}</div>',
                          '<div class="ctt-dms-listing-wizard-page-view-dms-list"></div>',
                          '</div>'].join('');

var TEMPLATE_LOADING_OVERLAY = Template.LOADING_OVERLAY;

/**
 * @method _initialize
 * @protected
 * @param {Object} configs
 */
prototype._initialize = function(configs) {
  var buttons;
  var cfg;

  cfg = {
    title: _('ctt_transfer_wizard_title'),
    bodyContent: TEMPLATE_PAGE_BODY.replace('${description}', _('ctt_dms_listing_wizard_page_view_description'))
  };

  cfg = dixim.extend(cfg, configs);
  buttons = [
    {
      text: _('ctt_transfer_wizard_button_label_next'),
      click: $.proxy(this._didClickNext, this),
      'class': 'ctt-dms-listing-wizard-page-view-button-next'
    },
    {
      text: _('ctt_transfer_wizard_button_label_cancel'),
      click: $.proxy(this._didClickCancel, this),
      align: 'left'
    },
    {
      text: _('ctt_transfer_wizard_button_label_delete'),
      click: $.proxy(this._didClickDelete, this),
      align: 'left',
      'class': 'ctt-dms-listing-wizard-page-view-button-delete'
    }
  ];

  cfg.buttons = buttons;
  superConstructor.prototype._initialize.call(this, cfg);

  this._loadingOverlay = null;
  this._ticker = null;
};

prototype._didRenderDialog = function(e) {
  var v = this._view;

  this._loadingOverlay = $(TEMPLATE_LOADING_OVERLAY);
  this._ticker = new TickerView({
    containerNode: $('.ctt-dms-listing-wizard-page-view-description', v),
    type: 'error'
  });

  superConstructor.prototype._didRenderDialog.call(this, e);
};

prototype._didOpenDialog = function(e) {
  var v = this._view;
  var list;
  var desc;

  superConstructor.prototype._didOpenDialog.call(this, e);

  list = $('.ctt-dms-listing-wizard-page-view-dms-list', v);
  desc = $('.ctt-dms-listing-wizard-page-view-description', v);
  list.height(Math.floor(v.height() - desc.outerHeight()));
};

prototype._didClickNext = function(e) {
  this.dispatchEvent(new Event(NEXT));
};

prototype._didClickCancel = function(e) {
  this.dispatchEvent(new Event(CANCEL));
};

prototype._didClickDelete = function(e) {
  this.dispatchEvent(new Event(DELETE));
};

prototype.getBodyContent = function() {
  return $('.ctt-dms-listing-wizard-page-view-dms-list', this._view);
};

prototype.enableNextButton = function() {
  this.enableButton('.ctt-dms-listing-wizard-page-view-button-next');
};

prototype.disableNextButton = function() {
  this.disableButton('.ctt-dms-listing-wizard-page-view-button-next');
};

prototype.enableDeleteButton = function() {
  this.enableButton('.ctt-dms-listing-wizard-page-view-button-delete');
};

prototype.disableDeleteButton = function() {
  this.disableButton('.ctt-dms-listing-wizard-page-view-button-delete');
};

prototype.hideDeleteButton = function() {
  this.disableButton('.ctt-dms-listing-wizard-page-view-button-delete');
  $('.ctt-dms-listing-wizard-page-view-button-delete', this._view.parent()).hide();
};

prototype.showActivityIndicator = function() {
  var o = this._loadingOverlay;
  var p = this._view;

  this.disableButtons();
  o.appendTo(p).width(p.innerWidth()).height(p.innerHeight()).show();
};

prototype.hideActivityIndicator = function() {
  this.enableButtons();
  this._loadingOverlay.hide(100).detach();
};

prototype.showError = function(error) {
  this._showError(error);
};

prototype._showError = function(error) {
  this._ticker.setText(error);
  this._ticker.show();
};

/**
 * @method scrollToElement
 * @param {jQuery} el
 * @param {Boolean} [animated=true]
 */
prototype.scrollToElement = function(el, animated) {
  var v = this._view;
  var list;
  var top;

  animated = typeof animated === 'undefined' ? true : animated;
  top = el.position().top;
  list = $('.ctt-dms-listing-wizard-page-view-dms-list', v);

  if (animated) {
    list.animate({scrollTop: top}, 200);
  } else {
    list.scrollTop(top);
  }
};

}());
