/**
 * @module dixim
 * @submodule common
 */
dixim.namespace('dixim.common');

/**
 * @module common
 * @submodule api-client-auto-delete
 */
(function() {
var ApiClientAutoDelete;
var prototype;
var suprtConstructor;
var ApiClient = dixim.common.ApiClient;
var Configs = dixim.ctt.Configs;

/**
 * Provides interfaces to delete automatically API.
 *
 * This API client supports two type of event handling method,
 * callback and event-subscription.
 *
 * The callback method can be specified as the parameter of each method.
 * (Such as request.success, request.error or request.complete.)
 * When the callback is called, an Event instance which is related to
 * the triggered method is passed to the callback.
 *
 * This API client is also an EventTarget, you can subscribe an event
 * by addEventListener().
 *
 * @class ApiClientAutoDelete
 * @constructor
 * @extends EventTarget
 * @param {Object} [configs]
 */
ApiClientAutoDelete = function(configs) {
    ApiClient.call(this, configs);
};

dixim.inherit(ApiClientAutoDelete, ApiClient);
dixim.common.ApiClientAutoDelete = ApiClientAutoDelete;
prototype = ApiClientAutoDelete.prototype;
superConstructor = ApiClientAutoDelete.suprtConstructor;

/**
 * Fetch availability setting.
 *
 * @method fetchAvailability
 * @param {Object} request
 * @param {Function} [request.success]
 * @param {Function} [request.error]
 * @param {Function} [request.complete]
 * @return {ApiClientSession} session
 */
prototype.fetchAvailability = function(request) {
    return this.doSimpleFetch.call(this, 'fetchAvailability', [Configs.get('apiArs'), '/settings/availability/get'].join(''), request);
};

/**
 * Set availability setting.
 *
 * @method setAvailability
 * @param {Object} request
 * @param {Boolean} [request.availability]
 * @param {Function} [request.success]
 * @param {Function} [request.error]
 * @param {Function} [request.complete]
 * @return {ApiClientSession} session
 */
prototype.setAvailability = function(request) {
    var query = {};

    query.availability = request.availability;

    request.dataType = 'text';

    return this.doSimpleMod.call(this, 'setAvailability', [Configs.get('apiArs'), '/settings/availability/set'].join(''), query, request);
};

/**
 * Fetch threshold setting.
 *
 * @method fetchThreshold
 * @param {Object} request
 * @param {Function} [request.success]
 * @param {Function} [request.error]
 * @param {Function} [request.complete]
 * @return {ApiClientSession} session
 */
prototype.fetchThreshold = function(request) {
    return this.doSimpleFetch.call(this, 'fetchThreshold', [Configs.get('apiArs'), '/settings/freeSpaceThreshold/get'].join(''), request);
};

/**
 * Set threshold setting.
 *
 * @method setThreshold
 * @param {Object} request
 * @param {Integer} [request.freeSpaceThreshold]
 * @param {Function} [request.success]
 * @param {Function} [request.error]
 * @param {Function} [request.complete]
 * @return {ApiClientSession} session
 */
prototype.setThreshold = function(request) {
    var query = {};

    query.freeSpaceThreshold = request.freeSpaceThreshold

    request.dataType = 'text';

    return this.doSimpleMod.call(this, 'setThreshold', [Configs.get('apiArs'), '/settings/freeSpaceThreshold/set'].join(''), query, request);
};

/**
 * Fetch remove protect setting.
 *
 * @method fetchRemoveProtect
 * @param {Object} request
 * @param {String[]} [request.objectIds]
 * @param {Function} [request.success]
 * @param {Function} [request.error]
 * @param {Function} [request.complete]
 * @return {ApiClientSession} session
 */
prototype.fetchRemoveProtect = function(request) {
    var query = {};

    query.objectIds = request.objectIds.join(',');

    return this.doSimpleMod.call(this, 'fetchRemoveProtect', [Configs.get('apiArs'), '/items/removeProtect/get'].join(''), query, request);
};

/**
 * Set remove protect setting.
 *
 * @method setRemoveProtect
 * @param {Object} request
 * @param {String[]} [request.objectIds]
 * @param {Boolean} [request.protectFlag]
 * @param {Function} [request.success]
 * @param {Function} [request.error]
 * @param {Function} [request.complete]
 * @return {ApiClientSession} session
 */
prototype.setRemoveProtect = function(request) {
    var query = {};

    query.objectIds = request.objectIds.join(',');
    query.protectFlag = request.protectFlag;

    request.dataType = 'text';

    return this.doSimpleMod.call(this, 'setRemoveProtect', [Configs.get('apiArs'), '/items/removeProtect/set'].join(''), query, request);
};

}());
