/**
 * @module dixim
 * @submodule common
 */
dixim.namespace('dixim.common');

/**
 * @module common
 * @submodule api-client-compress
 */
(function() {
var ApiClientCompress;
var prototype;
var suprtConstructor;
var ApiClient = dixim.common.ApiClient;
var Configs = dixim.ctt.Configs;

/**
 * Provides interfaces to compress contents API.
 *
 * This API client supports two type of event handling method,
 * callback and event-subscription.
 *
 * The callback method can be specified as the parameter of each method.
 * (Such as request.success, request.error or request.complete.)
 * When the callback is called, an Event instance which is related to
 * the triggered method is passed to the callback.
 *
 * This API client is also an EventTarget, you can subscribe an event
 * by addEventListener().
 *
 * @class ApiClientCompress
 * @constructor
 * @extends EventTarget
 * @param {Object} [configs]
 */
ApiClientCompress = function(configs) {
    ApiClient.call(this, configs);
};

dixim.inherit(ApiClientCompress, ApiClient);
dixim.common.ApiClientCompress = ApiClientCompress;
prototype = ApiClientCompress.prototype;
superConstructor = ApiClientCompress.suprtConstructor;

/**
 * Fetch availability.
 *
 * @method fetchAvailability
 * @param {Object} request
 * @param {Function} [request.success]
 * @param {Function} [request.error]
 * @param {Function} [request.complete]
 * @return {ApiClientSession} session
 */
prototype.fetchAvailability = function(request) {
    return this.doSimpleFetch.call(this, 'fetchAvailability', [Configs.get('apiAts'), '/availability/get'].join(''), request);
};

/**
 * Set availability.
 *
 * @method setAvailability
 * @param {Object} request
 * @param {Boolean} [request.availability]
 * @param {Function} [request.success]
 * @param {Function} [request.error]
 * @param {Function} [request.complete]
 * @return {ApiClientSession} session
 */
prototype.setAvailability = function(request) {
    var query = {};

    query.availability = request.availability;

    request.dataType = 'text';

    return this.doSimpleMod.call(this, 'setAvailability', [Configs.get('apiAts'), '/availability/set'].join(''), query, request);
};

/**
 * Fetch compress preset.
 *
 * @method fetchPreset
 * @param {Object} request
 * @param {Function} [request.success]
 * @param {Function} [request.error]
 * @param {Function} [request.complete]
 * @return {ApiClientSession} session
 */
prototype.fetchPreset = function(request) {
    return this.doSimpleFetch.call(this, 'fetchPreset', [Configs.get('apiAts'), '/preset/get'].join(''), request);
};

/**
 * Set compress preset.
 *
 * @method setPreset
 * @param {Object} request
 * @param {Integer} [request.id]
 * @param {Function} [request.success]
 * @param {Function} [request.error]
 * @param {Function} [request.complete]
 * @return {ApiClientSession} session
 */
prototype.setPreset = function(request) {
    var query = {};

    query.id = request.id;

    request.dataType = 'text';

    return this.doSimpleMod.call(this, 'setPreset', [Configs.get('apiAts'), '/preset/set'].join(''), query, request);
};

/**
 * Set compress reservation.
 *
 * @method setReservation
 * @param {Object} request
 * @param {String} [request.objectId]
 * @param {Function} [request.success]
 * @param {Function} [request.error]
 * @param {Function} [request.complete]
 * @return {ApiClientSession} session
 */
prototype.setReservation = function(request) {
    var query = {};

    query.objectId = request.objectId;

    request.dataType = 'text';

    return this.doSimpleMod.call(this, 'setReservation', [Configs.get('apiAts'), '/reservation/add'].join(''), query, request);
};

}());
