/**
 * @module dixim
 * @submodule common 
 */
dixim.namespace('dixim.common');

/**
 * @module common
 * @submodule home-menu-view
 */

(function() {
var HomeMenuView;
var prototype;
var superConstructor;
var _ = dixim.ctt.ResourceBundle.get;
var Event = dixim.event.Event;
var EventTarget = dixim.event.EventTarget;
var UiUtils = dixim.common.UiUtils;
var $ = dixim.ctt.jQuery;

/**
 * @class HomeMenuView
 * @constructor
 * @param {Object} configs
 */
HomeMenuView = function(configs) {
    EventTarget.call(this);
    this._initialize(configs);
};

dixim.inherit(HomeMenuView, EventTarget);
dixim.common.HomeMenuView = HomeMenuView;
prototype = HomeMenuView.prototype;
superConstructor = HomeMenuView.superConstructor;

var MENU = 'menu';

/**
 * @method _initialize
 * @protected
 * @param {Object} configs
 */
prototype._initialize = function(configs) {
    configs = configs || {};

    this._title = _('common_menu_title_home');
    this._uiUtils = UiUtils;
    this._uiUtils.switchTopMenuCode(true);
};

/**
 * @method show
 */
prototype.show = function() {
    if ($('header').length === 0) {
        $('head').append(['<title>', _('app_name'), '</title>'].join(''));
        $('body').append([
            '<header data-role="header" data-position="fixed" data-tap-toggle="false">',
            '<div class="action_bar_top">',
            '<div class="bar_inner">',
            '<div class="bar_contents">',
            '<p class="trigger_mn2">', _('app_name'), '</p>',
            '<div class="trigger_mn">',
            '<div></div>',
            '<div></div>',
            '<div></div>',
            '</div>',
            '<div class="bar_btn_box cf">',
            '<div id="hc_usb" class="ico_hd_usb bar_btn">',
            '</div>',
            '<div id="hc_search" class="ico_hd_search bar_btn">',
            '</div>',
            '</div>',
            '</div>',
            '</div>',
            '</div>',
            '<div class="action_bar">',
            '<div class="bar_inner">',
            '<div class="bar_contents">',
            '<p class="art_tit">', this._title, '</p>',
            '<a class="btn_prev">', '</a>',
            '<div class="bar_btn_box">',
            '<div id="ac_setting" class="ico_ac_setting bar_btn">',
            '</div>',
            '<div id="ac_refresh" class="ico_ac_refresh bar_btn">',
            '</div>',
            '</div>',
            '</div>',
            '</div>',
            '</div>',
            '<div class="action_bar_bottom">',
            '<div class="bar_inner">',
            '<div class="bar_contents">', '</div>',
            '</div>',
            '</div>',
            '</header>',
        ].join(''));
    }

    if ($('.aside').length === 0) {
        $('body').append([
            '<div class="aside">',
            '<nav class="container_mn" data-enhance="false">',
            '<ul id="sidebar_menu">', '</ul>',
            '<div class="company">', '</div>',
            '</nav>',
            '</div>',
        ].join(''));
    }

    if ($('.rootPage').length === 0) {
        $('body').append([
            '<article class="rootPage">', '</article>',
        ].join(''));
    }
};

/**
 * @method hide
 */
prototype.hide = function() {
    $('header,.aside,.rootPage').remove();
};

prototype.setEffect = function() {
    UiUtils.cleanActionBar();
    $('.action_bar_bottom,.btn_prev,.bar_btn').hide();
    $('.art_tit').text(this._title);
    $('.btn_prev').hide();
    $('.trigger_mn').off('click').on('click', function() {
        $('.container_mn').toggleClass('show');
        $(this).toggleClass('active');
    });

    $('article,.container_mn').off('click').on('click', function() {
        $('.container_mn').removeClass('show');
    });
};

prototype.addRootBase = function() {
    $('.rootPage').html([
        '<div class="contents" data-enhance="false">',
        '<h2 id="tit_page"></h2>',
        '<div class="contents_inner">',
        '<ul id="root_page_menu" class="list_btn list_next list_3col">', '</ul>',
        '</div>',
        '</div>',
    ].join(''));
};

prototype.addSidebarMenu = function(data) {
    if ($(['#sidebar_', data.class].join('')).length !== 0) {
        return;
    }

    $('#sidebar_menu').append([
        '<li id="sidebar_', data.class, '">',
        '<a href="#">',
        '<div class="', data.class, '"></div>',
        _(data.titleId),
        '</a>',
        '</li>',
    ].join(''));
    $('#sidebar_menu li:last-child a').on('click', data, dixim.proxy(this._clickMenu, this));
};

prototype.addRootPageMenu = function(data) {
    if ($(['#root_page_menu_', data.class].join('')).length !== 0) {
        return;
    }

    $('#root_page_menu').append([
        '<li id="root_page_menu_', data.class, '">',
        '<a href="#">',
        '<div class="list_iconbox"><img class="rspd" src="', data.image, '" width="100" height="100" alt="#"/></div>',
        '<h3 class="txt_m">', _(data.titleId), '</h3>',
        '<p class="txt_gray">', _(data.descriptionId), '</p>',
        '</a>',
        '</li>',
    ].join(''));
    $('#root_page_menu li:last-child a').on('click', data, dixim.proxy(this._clickMenu, this));
};

prototype._clickMenu = function(e) {
    this.dispatchEvent(new Event(MENU, e.data));
};

prototype.cleanRootPage = function() {
    $('.rootPage').empty();
};

}());
