/**
 * @module dixim
 * @submodule server
 */
dixim.namespace('dixim.server');

/**
 * @module server
 * @submodule extensions-view
 */

(function() {
var ExtensionsView;
var prototype;
var superConstructor;
var _ = dixim.ctt.ResourceBundle.get;
var Event = dixim.event.Event;
var EventTarget = dixim.event.EventTarget;
var UiUtils = dixim.common.UiUtils;
var $ = dixim.ctt.jQuery;
var escape = dixim.xml.escape;

/**
 * @class ExtensionsView
 * @constructor
 * @param {Object} configs
 */
ExtensionsView = function(configs) {
    EventTarget.call(this);
    this._initialize(configs);
};
dixim.inherit(ExtensionsView, EventTarget);
dixim.server.ExtensionsView = ExtensionsView;
prototype = ExtensionsView.prototype;
superConstructor = ExtensionsView.superConstructor;

var SELECT = 'select';
var FORMAT = 'format';
var DELETE = 'delete';
var EDIT = 'edit';
var APPEND = 'append';
var PREV = 'prev';

/**
 * @method _initialize
 * @protected
 * @param {Object} configs
 */
prototype._initialize = function(configs) {
    configs = configs || {};

    configs.id = configs.id || '';
    this._id = [configs.id, 'extensions'].join('');

    this._dialog = null;
    this._title = _('server_menu_extensions');
    this._uiUtils = UiUtils;
};

/**
 * @method show
 */
prototype.show = function() {
    $('.rootPage').html([
        '<div class="contents" data-enhance="false">',
        '<h2 id="tit_page">', this._title, '</h2>',
        '<div class="contents_inner">',
        '<div id="extensions_list">',
        '<table class="tbl_list">',
        '<colgroup>',
        '<col span="1" class="checkbox">',
        '<col span="1" class="list_info">',
        '</colgroup>',
        '<tbody>', '</tbody>',
        '</table>',
        '</div>',
        '</div>',
        '</div>',
    ].join(''));

    this._uiUtils.cleanActionSettingBar();
    this._uiUtils.cleanActionBar();
    this._uiUtils.setActionBar('ab_select', dixim.proxy(this._clickSelect, this));
    this._uiUtils.setActionBar('ab_format', dixim.proxy(this._clickFormat, this));
    this._uiUtils.setActionBar('ab_delete', dixim.proxy(this._clickDelete, this));
    this._uiUtils.setActionBar('ab_edit', dixim.proxy(this._clickEdit, this));
    this._uiUtils.setActionBar('ab_append', dixim.proxy(this._clickAppend, this));

    $('.art_tit').text(this._title);
    $('.btn_prev').show().one('click', dixim.proxy(this._clickPrev, this));
};

/**
 * @method hide
 */
prototype.hide = function() {
    $('.rootPage').empty();
};

prototype.addSharedType = function(data) {
    $('#extensions_list table tbody').append([
        '<tr>',
        '<td>',
        '<label class="select-pointer">',
        '<input type="checkbox" />',
        '<span>', '</span>',
        '</label>',
        '</td>',
        '<td>',
        '<h4 class="type-extension txt_m">', escape(data.extension), '</h4>',
        '<div class="type-mime-type list_detail txt_s">',
        '<p>', escape(data.mimeType), '</p>',
        '</div>',
        '</td>',
        '</tr>',
    ].join(''));
};

prototype.error = function(text) {
    $('#shared_type_error').remove();
    $('.contents_inner').append([
        '<div id="shared_type_error" class="error-text-field txt_none">',
        '<span>', text, '</span>',
        '</div>',
    ].join(''));
};

prototype.switchSelect = function() {
    var numberOfNotChecked = $('.tbl_list [type="checkbox"]').not(':checked').length;

    if (numberOfNotChecked > 0) {
        $('.tbl_list [type="checkbox"]').prop('checked', true);
    } else {
        $('.tbl_list [type="checkbox"]').prop('checked', false);
    }
};

prototype._clickSelect = function() {
    this.dispatchEvent(new Event(SELECT));
};

prototype._clickFormat = function() {
    this.dispatchEvent(new Event(FORMAT));
};

prototype._clickDelete = function() {
    var sharedTypes = [];

    $('.tbl_list [type="checkbox"]:checked').each(function() {
        sharedTypes.push({
            extension: $(this).closest('tr').find('.type-extension').text(),
            mimeType: $(this).closest('tr').find('.type-mime-type').text(),
        });
    });
    this.dispatchEvent(new Event(DELETE, {sharedTypes: sharedTypes}));
};

prototype._clickEdit = function() {
    var sharedTypes = [];

    $('.tbl_list [type="checkbox"]:checked').each(function() {
        sharedTypes.push({
            extension: $(this).closest('tr').find('.type-extension').text(),
            mimeType: $(this).closest('tr').find('.type-mime-type').text(),
        });
    });
    this.dispatchEvent(new Event(EDIT, {sharedTypes: sharedTypes}));
};

prototype._clickAppend = function() {
    this.dispatchEvent(new Event(APPEND));
};

prototype._clickPrev = function() {
    this.dispatchEvent(new Event(PREV));
};

prototype.cleanExtensionList = function() {
    $('#extensions_list table tbody, #shared_type_error').empty();
};

}());
