/**
 * @module dixim
 * @submodule server
 */
dixim.namespace('dixim.server');

/**
 * @module server
 * @submodule server-menu-controller
 */

(function() {
var ServerMenuController;
var prototype;
var superConstructor;
var ServerMenuView = dixim.server.ServerMenuView;
var EventTarget = dixim.event.EventTarget;
var ServerBootController = dixim.server.ServerBootController;
var FriendlyNameController = dixim.server.FriendlyNameController;
var PermissionMenuController = dixim.server.PermissionMenuController;
var ExtensionsController = dixim.server.ExtensionsController;
var PublicFolderController = dixim.server.PublicFolderController;
var LanguageController = dixim.server.LanguageController;
var UiFunctionManager = dixim.ctt.util.UiFunctionManager;
var Configs = dixim.ctt.Configs;
var ResourceBundle = dixim.ctt.ResourceBundle;

/**
 * @class ServerMenuController
 * @constructor
 * @param {Object} configs
 */
ServerMenuController = function(configs) {
    EventTarget.call(this);
    this._initialize(configs);
};

dixim.inherit(ServerMenuController, EventTarget);
dixim.server.ServerMenuController = ServerMenuController;
prototype = ServerMenuController.prototype;
superConstructor = ServerMenuController.superConstructor;

UiFunctionManager.set('server');

var BOOT_SERVER = 'bootServer';
var FRIENDLY_NAME = 'friendlyName';
var PERMISSION = 'permission';
var EXTENSIONS = 'extensions';
var PUBLIC_FOLDER = 'publicFolder';
var LANGUAGE = 'language';
var PREV = 'prev';

/**
 * @method _initialize
 * @protected
 * @param {Object} configs
 */
prototype._initialize = function(configs) {
    configs = configs || {};

    ResourceBundle.reset();
    Configs.set('resourceBundlePath', 'lang/server/');

    this._view = new ServerMenuView(configs);
    this._view.addEventListener(PREV, this._clickPrev, this);
    this._view.addEventListener(BOOT_SERVER, this._clickBootServer, this);
    this._view.addEventListener(FRIENDLY_NAME, this._clickFriendlyName, this);
    this._view.addEventListener(PERMISSION, this._clickPermission, this);
    this._view.addEventListener(EXTENSIONS, this._clickExtensions, this);
    this._view.addEventListener(PUBLIC_FOLDER, this._clickPublicFolder, this);
    this._view.addEventListener(LANGUAGE, this._clickLanguage, this);

    this._parentContext = configs.parentContext;
};

/**
 * @method start
 */
prototype.start = function() {
    this._view.show();
};

/**
 * @method stop
 */
prototype.stop = function() {
    this._view.hide();
};

prototype._clickPrev = function() {
    this.stop();
    this._parentContext.start();
};

prototype._clickBootServer = function() {
    var controller;
    var query = {};

    query.parentContext = this;
    controller = new ServerBootController(query);
    controller.start();
};

prototype._clickFriendlyName = function() {
    var controller;
    var query = {};

    query.parentContext = this;
    controller = new FriendlyNameController(query);
    controller.start();
};

prototype._clickPermission = function() {
    var controller;
    var query = {};

    query.parentContext = this;
    controller = new PermissionMenuController(query);
    controller.start();
};

prototype._clickExtensions = function() {
    var controller;
    var query = {};

    query.parentContext = this;
    controller = new ExtensionsController(query);
    controller.start();
};


prototype._clickPublicFolder = function() {
    var controller;
    var query = {};

    query.parentContext = this;
    controller = new PublicFolderController(query);
    controller.start();
};

prototype._clickLanguage = function() {
    var controller;
    var query = {};

    query.parentContext = this;
    controller = new LanguageController(query);
    controller.start();
};

}());
